.. Nashpy documentation main file, created by
   sphinx-quickstart on Sat Jun 17 12:30:44 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Nashpy's documentation!
==================================

This is a Python library used for the computation of equilibria in 2 player
strategic form games.

.. toctree::
   :maxdepth: 2

   tutorial/index.rst
   how-to/index.rst
   discussion/index.rst
   reference/index.rst
   contributing/index.rst




Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
